@@ -143,6 +143,9 @@ INTERNALERROR_DFWERROR = 'InternalError.DfwError'
 # SQL statement error
 INTERNALERROR_EXESQLERROR = 'InternalError.ExeSqlError'
 
+# 
+INTERNALERROR_EXECUTESQLERROR = 'InternalError.ExecuteSQLError'
+
 # File transfer exception
 INTERNALERROR_FTPERROR = 'InternalError.FtpError'
 
@@ -356,6 +359,9 @@ OPERATIONDENIED_DELETEROOTACCOUNTERROR = 'OperationDenied.DeleteRootAccountError
 # This instance needs permissions to use this feature.
 OPERATIONDENIED_FUNCTIONDENIED = 'OperationDenied.FunctionDenied'
 
+# 
+OPERATIONDENIED_INSTTYPENOTSUPPORT = 'OperationDenied.InstTypeNotSupport'
+
 # Instance locks are in conflict. Please try again later.
 OPERATIONDENIED_INSTANCELOCKERCONFLICT = 'OperationDenied.InstanceLockerConflict'
 
