@@ -50,6 +50,9 @@ INTERNALERROR_GETROOMCACHEIPERROR = 'InternalError.GetRoomCacheIpError'
 # Failed to get room information.
 INTERNALERROR_GETROOMFROMCACHEERROR = 'InternalError.GetRoomFromCacheError'
 
+# Parameter error.
+INVALIDPARAMETER = 'InvalidParameter'
+
 # Parameter value is out of range.
 INVALIDPARAMETER_OUTOFRANGE = 'InvalidParameter.OutOfRange'
 
@@ -65,6 +68,9 @@ INVALIDPARAMETER_USERIDS = 'InvalidParameter.UserIds'
 # Invalid RoomId.
 INVALIDPARAMETERVALUE_ROOMID = 'InvalidParameterValue.RoomId'
 
+# Missing parameter.
+MISSINGPARAMETER = 'MissingParameter'
+
 # `AccessKey` parameter missing.
 MISSINGPARAMETER_ACCESSKEY = 'MissingParameter.AccessKey'
 
